@@ -1,5 +1,5 @@
-#[cfg(feature="serde_macros")]
+#[cfg(feature="serde_derive")]
 include!("jsontypes.rs.in");
 
-#[cfg(not(feature="serde_macros"))]
+#[cfg(not(feature="serde_derive"))]
 include!(concat!(env!("OUT_DIR"), "/jsontypes.rs"));
